@@ -1,10 +1,17 @@
 from logging import warning
 
-from . import ENGHo
-from . import Series
-from . import EPH
-from . import BancoMundial
-from . import YahooFinance
+try:
+    from . import ENGHo
+    from . import Series
+    from . import EPH
+    from . import BancoMundial
+    from . import YahooFinance
+except ImportError:
+    import ENGHo
+    import Series
+    import EPH
+    import BancoMundial
+    import YahooFinance
 
 class INDECError(Exception):
     pass
